/*
	Paramete file for YUV(CCIR 601-1) to RGB-888 color space convertor
	
	File		: RGB2YUV_conv.h

	Designer	: Masami IKURA [ MASATIKU ]
	Organize	: KURUSUGAWA Electronics Industry Inc,.
	Revision	: Rev0.1
	Syntax		: NSL language set
	Resume		: 110517 first design.
*/

// Original equation : 8bit full scale
//	Y =  0.25700*R + 0.50400*G + 0.09800*B + 16
//	U = -0.14800*R - 0.29100*G + 0.43900*B + 128
//	V =  0.43900*R - 0.36800*G - 0.07100*B + 128

//		x4096 coefficient
//		x256  constant value

// Coefficient for Y.
	#define		COEF_Y1		16'd1053	// R
	#define		COEF_Y2		16'd2064	// G
	#define		COEF_Y3		16'd401		// B
	#define		COEF_Y4		16'd4096	// Constant value (+)

// Coefficient for U.
	#define		COEF_U1		16'd606		// R
	#define		COEF_U2		16'd1192	// G
	#define		COEF_U3		16'd1798	// B
	#define		COEF_U4		16'd32768	// Constant value (+)

// Coefficient for V.
	#define		COEF_V1		16'd1798	// R
	#define		COEF_V2		16'd1507	// G
	#define		COEF_V3		16'd291		// B
	#define		COEF_V4		16'd32768	// Constant value (+)

declare RGB2YUV_conv {

// RGB-888 data input
	input		R_in[8] ;
	input		G_in[8] ;
	input		B_in[8] ;

// CCIR-656 data output
	output		Y_out[8] ;
	output		U_out[8] ;
	output		V_out[8] ;
	
// Control lines
	input		VSYNCin ;				// VSYNC in
	input		HSYNCin ;				// HSYNC in
	
	output		VSYNCout ;				// Pipeline clock conpensated VSYNC out
	output		HSYNCout ;				// Pipeline clock conpensated HSYNC out

// Function control
	func_in		ConvStart( R_in, G_in, B_in) ;
	func_out	ConvFinish( Y_out, U_out, V_out ) ;
}
