`timescale 1ns / 1ps

module	tb ;
	parameter		tCYC=20;
	parameter		tPD=(tCYC/10);

	integer			i, j, k ;
	
	reg				p_reset;
	reg				m_clock;

	reg		[7:0]	R_in;
	reg		[7:0]	G_in;
	reg		[7:0]	B_in;

	wire	[7:0]	Y_out;
	wire	[7:0]	U_out;
	wire	[7:0]	V_out;

	wire	[7:0]	R_out;
	wire	[7:0]	G_out;
	wire	[7:0]	B_out;

	reg				ConvStart;
	wire			ConvFinish1;
	wire			ConvFinish2;

	reg				VSYNCin;
	reg				HSYNCin;
	
	reg		[24:0]	Counter ;
	
	reg		[23:0]	hld_sRGB ;
	reg		[23:0]	hld_sYUV ;
	reg		[23:0]	hld_sRGB2 ;
	reg		[23:0]	hld_sYUV2 ;
	reg		[23:0]	hld_dRGB ;
	

//
	RGB2YUV_conv	R2Y (
		.p_reset	(p_reset) ,
		.m_clock	(m_clock)  ,
		.R_in		(R_in)  ,
		.G_in		(G_in)  ,
		.B_in		(B_in)  ,
		.Y_out		(Y_out)  ,
		.U_out		(U_out)  ,
		.V_out		(V_out)  ,
		.VSYNCin	(VSYNCin)  ,
		.HSYNCin	(HSYNCin)  ,
		.VSYNCout	()  ,
		.HSYNCout	()  ,
		.ConvStart	(ConvStart)  ,
		.ConvFinish	(ConvFinish1) 
	);

	YUV2RGB_conv	Y2R (
		.p_reset	(p_reset) ,
		.m_clock	(m_clock)  ,
		.Yin		(Y_out)  ,
		.Uin		(U_out)  ,
		.Vin		(V_out)  ,
		.Rout		(R_out)  ,
		.Gout		(G_out)  ,
		.Bout		(B_out)  ,
		.VSYNCin	(VSYNCin)  ,
		.HSYNCin	(HSYNCin)  ,
		.VSYNCout	()  ,
		.HSYNCout	()  ,
		.ConvStart	(ConvFinish1)  ,
		.ConvFinish	(ConvFinish2) 
	);

	initial forever
		#(tCYC/2)	m_clock = ~m_clock ;

	initial begin
		#tPD
			p_reset	= 1 ;
			m_clock	= 1 ;
			R_in	= 0 ;
			G_in	= 0 ;
			B_in	= 0 ;
			ConvStart = 0 ;
			VSYNCin = 0 ;
			HSYNCin = 0 ;
			
		#(tCYC*4)
			p_reset	= 0 ;
		#(tCYC*4)
			while (Counter != 25'h1000000) begin
				#(tCYC*2)
					R_in = Counter[23:16] ;
					G_in = Counter[15:8] ;
					B_in = Counter[7:0] ;
				#(tCYC*1)
					ConvStart = 1 ;
				#(tCYC*1)
					ConvStart = 0 ;
				#(tCYC*2)
					if ( Counter[7:0] == 8'h00 ) begin
						HSYNCin = 1 ;
					end else begin
						HSYNCin = 0 ;
					end
			end
		#(tCYC*16)
			$display ("Time = %t : Simuration finish !", $time);
		#(tCYC*16)
			$stop;
	end
	
	always @(posedge m_clock)
	begin
		if ( p_reset ) begin
			Counter = 0 ;
		end else begin
			if ( ConvStart ) begin
				Counter <= Counter + 1 ;
			end
		end
	end

	always @(posedge m_clock)
	begin
		if ( p_reset ) begin
			hld_sRGB = 0 ;
			hld_sRGB2 = 0 ;
			hld_sYUV = 0 ;
			hld_sYUV2 = 0 ;
			hld_dRGB = 0 ;
		end else begin
			if ( ConvFinish1 ) begin
				hld_sRGB	<= { R_in,  G_in,  B_in } ;
				hld_sYUV	<= { Y_out, U_out, V_out } ;
			end
			if ( ConvFinish2 ) begin
				hld_sRGB2	<= hld_sRGB ;
				hld_sYUV2	<= hld_sYUV ;
				hld_dRGB	<= { R_out, G_out, B_out } ;
			end
		end
	end

endmodule
